menu = function(){
  # We check that library 'FuzzyNumbers' is installed
  if (!require('FuzzyNumbers'))
    stop("Please, install library 'FuzzyNumbers' before continuing.")
  library('FuzzyNumbers') # start


  cat(paste("Insert the quantity of trapezoidal fuzzy numbers to carry out the ranking"))
  cantidadNumeros<-scan(n=1)
  # if a positive number has been loaded
  if(cantidadNumeros>0){
    # Initializing the vectors for parameters as null
    a=NULL
    b=NULL
    c=NULL
    d=NULL
    etiqueta = NULL

    cat(paste("\nPlease, insert each fuzzy number through its corners (a,b,c,d) and a label (text)\n"))
    cat(paste("\n(recall b=c if it is triangular)\n"))
    cat(paste("\n(make sure a<=b<=c<=d)\n"))

    # caption of the corners of the fuzzy numbers
    for(i in 1:cantidadNumeros){
      cat(paste("\nCorners of the trapezoidal fuzzy number",i,"are :\n"))
      num=scan(nmax =4)
      # We check that corners are correctly ordered as real numbers
      if(num[1]<= num[2] && num[2]<= num[3] && num[3] <= num[4]){
        a=c(a,num[1])#contiene todas las a de los numeros difusos
        b=c(b,num[2])
        c=c(c,num[3])
        d=c(d,num[4])
        # caption of labels
        cat(paste("Insert the label of this fuzzy number\n"))
        etiqueta= c(etiqueta,scan(,what = character(),1))

      }else{#si algun valor es incorrecto que pare de introducir numeros
        cat(paste("Failure: corners are incorrectly ordered. END."))
        return(0)
      }

    }
  }
  else{
    cat(paste("Failure: incorrect quantity of fuzzy numbers. END."))
    return(0)

  }

  # computation of ranking
  valorRanking<-Ranking2FN(c(a[1],b[1],c[1],d[1]),c(a[2],b[2],c[2],d[2]), etiqueta[1],etiqueta[2])


  # definition of the trapezoidal fuzzy number for plotting
  A<-TrapezoidalFuzzyNumber(a[1],b[1],c[1],d[1])
  B<-TrapezoidalFuzzyNumber(a[2],b[2],c[2],d[2])

  A1<-as.PiecewiseLinearFuzzyNumber(A, knot.n=0)
  B1<-as.PiecewiseLinearFuzzyNumber(B, knot.n=0)

  # computation of the appropriate interval for plotting
  FNa<-c(a[1],b[1],c[1],d[1])
  FNb<-c(a[2],b[2],c[2],d[2])
  m1<-min(FNa,FNb)
  m2<-max(FNa,FNb)
  l<-m2-m1
  l1<-m1-0.15*l
  l2<-m2+0.15*l

  # Plotting fuzzy numbers and ranking (as label of the plotting)
  plot(A1, xlim=c(l1,l2), main="Ranking trapezoidal fuzzy numbers",lwd=2, col="red")
  plot(B1, add=TRUE, lwd=2,col="blue")
  legend("topright", legend=c(etiqueta[1], etiqueta[2]), col=c("red","blue"), lty=c(1,1), title = valorRanking,bg='lightblue')


}
